@@ -1,8 +1,5 @@
 package POSIX::RT::SharedMem;
-{
-  $POSIX::RT::SharedMem::VERSION = '0.08';
-}
-
+$POSIX::RT::SharedMem::VERSION = '0.09';
 use strict;
 use warnings;
 
@@ -10,7 +7,6 @@ use Exporter 5.57 'import';
 use XSLoader;
 use Carp qw/croak/;
 use Fcntl qw/O_RDONLY O_WRONLY O_RDWR O_CREAT/;
-use Const::Fast;
 
 use File::Map 'map_handle';
 
@@ -18,8 +14,7 @@ our @EXPORT_OK = qw/shared_open shared_unlink/;
 
 XSLoader::load(__PACKAGE__, __PACKAGE__->VERSION);
 
-const my $fail_fd       => -1;
-const my $default_perms => oct '600';
+my $default_perms = oct '600';
 
 my %flag_for = (
 	'<'  => O_RDONLY,
@@ -60,23 +55,31 @@ sub shared_open {    ## no critic (Subroutines::RequireArgUnpacking)
 
 1;    # End of POSIX::RT::SharedMem
 
+#ABSTRACT: Create/open or unlink POSIX shared memory objects in Perl
 
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-POSIX::RT::SharedMem
+POSIX::RT::SharedMem - Create/open or unlink POSIX shared memory objects in Perl
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
  use POSIX::RT::SharedMem qw/shared_open/;
 
- shared_open my $map, '/some_file', '>+', size => 1024, perms => oct(777);
+ shared_open my $map, '/some_file', '+>', size => 1024, perms => oct(777);
+
+=head1 DESCRIPTION
+
+This module maps POSIX shared memory into a variable that can be read just like any other variable, and it can be written to using standard Perl techniques such as regexps and C<substr>, B<as long as they don't change the length of the variable>.
 
 =head1 FUNCTIONS
 
@@ -96,11 +99,11 @@ This determines the size of the map. If the map is map has writing permissions a
 
 =item * perms
 
-This determines the permissions with which the file is created (if $mode is '+>'). Default is 0600.
+This determines the permissions with which the file is created (if $mode is C<< +> >>). Default is 0600.
 
 =item * offset
 
-This determines the offset in the file that is mapped. Default is 0.
+This determines the offset in the file that is mapped. Default is C<0>.
 
 =item * flags
 
@@ -108,7 +111,7 @@ Extra flags that are used when opening the shared memory object (e.g. C<O_EXCL>)
 
 =back
 
-It returns a filehandle that can be used to with L<stat>, L<chmod>, L<chown>. You should not assume you can read or write directly from it.
+It returns a filehandle that can be used to with L<stat>, L<chmod>, L<chown>. For portability you should not assume you can read or write directly from it.
 
 =head2 shared_unlink $name
 
@@ -118,8 +121,14 @@ Remove the shared memory object $name from the namespace. Note that while the sh
 
 =over 4
 
+=item * SysV::SharedMem
+
+This is a rather similar module that works with SysV shared memory. SysV has confusing ideas of how to identify a segment, as well as having various special case functions that are handled by standard filehandle calls in POSIX shared memory. This module should usually be preferred unless portability requires otherwise.
+
 =item * L<File::Map>
 
+This is used to map the shared memory handle into a scalar. If your processes have a parent-child relationship, you may want to look at C<map_anonymous> instead.
+
 =back
 
 =head1 AUTHOR
@@ -134,9 +143,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
-#ABSTRACT: Create/open or unlink POSIX shared memory objects in Perl
-
